%  acadiathesis.cls
%  Colin Macdonald (cbm[at]member.fsf.org, 028741m[at]acadiau.ca)
%
%  Anyone may use this for any purpose as far as i'm concerned.
%  I would ask that you leave this text intact and include a
%  comment in your actual thesis .tex file (however, please do
%  not feel that you have to mention me anywhere in the rendered
%  copy of your thesis.  If you choose to redistribute this, please
%  give me credit.  If you make changes, please forward them back to me
%  at the address above.  As far as i'm concerned, you should treat this
%  document as you would BSD-licensed code.
%
%  The author below notes that you cannot rename this file to
%  ubcthesis.cls so please respect that.
%
%  modified from ubsthesis.cls (original header follows)
%  -------------------------------------------------------
%
%  ubcthesis.cls
%  Anders G S Svensson  <svensson@math.ubc.ca>
%  $Revision: 1.14 $
%  $Date: 1996/01/21 11:18:58 $

%  A thesis class for the University of British Columbia, Canada.
%  Based on my lnotes.cls.

%  ** Caveat Emptor ***************************************************
%  Use of this document class does not guarantee a format or layout
%  conforming with the regulations of the Faculty of Graduate Studies.
%  Consult their booklet "Instructions for the Preparation of Graduate
%  Theses" and the Special Collections Division of Main Library for the
%  official word.
%  ********************************************************************
%
%  On the other hand, this class does satisfy all the requirements as far as
%  I know. Please let me know if you discover any problems.

%  Please do not make modifications to this file under the name
%  ubcthesis.cls.

\def\Revision@$#1 #2 ${v#2}
\def\Date@$#1 #2 #3 ${#2}

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{acadiathesis}[\Date@$Date: 1996/01/21 11:18:58 $
   Acadia Thesis Class \Revision@$Revision: 1.00 $]

\def\UnofficialOption@#1{%
   \DeclareOption{#1}%
      {\UnofficialOptionWarning@{#1}\PassOptionsToClass{#1}{lnotes}}} 
\def\UnofficialOptionWarning@#1{%
   \Warning@{Option "#1" unacceptable for a submitted thesis}}
\def\UnsupportedOption@#1{%
   \DeclareOption{#1}{%
      \ClassError{acadiathesis}{Option "#1" unsupported}{Sorry.}}}
\def\Warning@#1{\typeout{**^^J** #1^^J**}}

\DeclareOption{balance}{%
   \Warning@{Option "balance" may produce unacceptable margins}%
   \PassOptionsToClass{balance}{lnotes}}

%  The default is a Ph.D. thesis. This information is only needed in the
%  title page. \degree can be used for any other possibility.

\DeclareOption{phd}{\AtEndOfClass{\degree{Doctor of Philosophy}}}
\DeclareOption{msc}{\AtEndOfClass{\degree{Master of Science}}}
\DeclareOption{bsch}{\AtEndOfClass{\degree{Bachelor of Science with Honours}}}
   
%  Because of the order in which \ProcessOptions executes code options (in
%  order of the \DeclareOption's) we have to be a little careful in making
%  11pt the default but still allowing 10pt as an (unofficial) option.
      
\DeclareOption{10pt}{\UnofficialOptionWarning@{10pt}%
   \def\ClassLoader@[{\LoadClass[10pt,}}
\DeclareOption{11pt}{\def\ClassLoader@[{\LoadClass[11pt,}}
\DeclareOption{12pt}{\def\ClassLoader@[{\LoadClass[12pt,}}
      
%  The default is for the front and backmatter to be single space (this is
%  allowed) and for the mainmatter to be double spaced (this is required).
%  The alldoublespace option makes the backmatter double spaced as well.
%  Your committee may want this for drafts. Double spacing for the main
%  text will probably not be necessary in the future, at which time I will
%  make singlespace the default. The current format requirements were written
%  in medieval times.

\DeclareOption{doublespace}{}% default
\DeclareOption{alldoublespace}{\AtEndOfClass{\let\BackSingle@\Double@}}
\DeclareOption{singlespace}{\UnofficialOptionWarning@{singlespace}%
   \AtEndOfClass{\let\Double@\Single@}}
\DeclareOption{openup}{%
   \AtEndOfClass{\def\singlebaselinestretch{1.16}
      \advance\singleparskip by 2pt}}
      
\UnofficialOption@{a4paper}
\UnofficialOption@{a5paper}
\UnofficialOption@{b5paper}
\UnofficialOption@{executivepaper}
\UnofficialOption@{landscape}
\UnofficialOption@{legalpaper}

%  With the notitlepage option, the title page is left up to the user.  

\DeclareOption{notitlepage}{%
   \AtEndOfClass{\renewcommand\maketitle{}}}
\DeclareOption{titlepage}{}% title page is automatic

%  Uglification on demand.
%
\DeclareOption{indent}{%
   \AtEndOfClass{\singleparskip\z@ \doubleparskip\z@ \parindent20pt}}

\UnsupportedOption@{twocolumn}
\UnsupportedOption@{twoside}
\UnsupportedOption@{openright}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{lnotes}}

\ExecuteOptions{11pt,phd}
\ProcessOptions\relax
\ClassLoader@[titlepage]{lnotes}[1996/01/11]

%  Left margin must be at least .25in.

\setlength\oddsidemargin{.25in}
\setlength\evensidemargin{.25in}

\setlength\textwidth{\paperwidth}
\addtolength\textwidth{-2.25in}
 
%  Is a \marginpar legal in a thesis anyway?
   
\setlength\marginparsep{6\p@}
\setlength\marginparwidth{1in}
\addtolength\marginparwidth{-12\p@}

%  Double spacing is evil, but this is required for the main text. :^(

\newskip\singleparskip  \newskip\doubleparskip

\def\singlesectparstretch{.5}
\def\doublesectparstretch{.25}
\def\singlelistparstretch{.25}
\def\doublelistparstretch{0}
\def\singlebaselinestretch{1}
\def\doublebaselinestretch{1.6}

\ifcase\@ptsize
   \setlength\parskip{6pt plus 1pt minus 1pt}
   \def\Single@{\global\doublespacefalse
      \global\let\baselinestretch\singlebaselinestretch
      \global\let\sectparstretch\singlesectparstretch
      \global\let\listparstretch\singlelistparstretch
      \global\parskip\singleparskip
      \global\skip\footins=9pt plus 4pt minus 2pt
      \singlespacehook \selectfont}
   \def\Double@{\global\doublespacetrue
      \global\let\baselinestretch\doublebaselinestretch
      \global\let\sectparstretch\doublesectparstretch
      \global\let\listparstretch\doublelistparstretch
      \global\parskip\doubleparskip
      \global\skip\footins=17pt plus 4pt minus 2pt
      \doublespacehook \selectfont}
\or
   \setlength\parskip{6.5pt plus 1pt minus 1pt}
   \def\Single@{\global\doublespacefalse
      \global\let\baselinestretch\singlebaselinestretch
      \global\let\sectparstretch\singlesectparstretch
      \global\let\listparstretch\singlelistparstretch
      \global\parskip\singleparskip
      \global\skip\footins=10pt plus 4pt minus 2pt
      \singlespacehook \selectfont}
   \def\Double@{\global\doublespacetrue
      \global\let\baselinestretch\doublebaselinestretch
      \global\let\sectparstretch\doublesectparstretch
      \global\let\listparstretch\doublelistparstretch
      \global\parskip\doubleparskip
      \global\skip\footins=18pt plus 4pt minus 2pt
      \doublespacehook \selectfont}
\or
   \setlength\parskip{7pt plus 1pt minus 1pt}
   \def\Single@{\global\doublespacefalse
      \global\let\baselinestretch\singlebaselinestretch
      \global\let\sectparstretch\singlesectparstretch
      \global\let\listparstretch\singlelistparstretch
      \global\parskip\singleparskip
      \global\skip\footins=10.8pt plus 4pt minus 2pt
      \singlespacehook \selectfont}
   \def\Double@{\global\doublespacetrue
      \global\let\baselinestretch\doublebaselinestretch
      \global\let\sectparstretch\doublesectparstretch
      \global\let\listparstretch\doublelistparstretch
      \global\parskip\doubleparskip
      \global\skip\footins=18.8pt plus 4pt minus 2pt
      \doublespacehook \selectfont}
\fi
      
\let\singlespacehook\relax
\let\doublespacehook\relax
      
\def\parstretch{1.6}
\AtBeginDocument{\singleparskip\parskip
   \doubleparskip=\parstretch\singleparskip
   \Single@}
      
\let\BackSingle@\Single@
      
%  Footnotes and captions can be single spaced.
      
\long\def\@makecaption#1#2{\single@
  \vskip\abovecaptionskip
  \sbox\@tempboxa{#1: #2}%
  \ifdim \wd\@tempboxa >\hsize
    #1: #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi 
  \vskip\belowcaptionskip}

\def\@makefntext#1{\single@
   \leavevmode\hbox to \z@{\hss\@makefnmark}#1}

\long\def\@savemarbox#1#2{%
   \global\setbox#1%
      \color@vbox
         \vtop{\single@ 
            \hsize\marginparwidth
            \@parboxrestore
            \@marginparreset
            #2%
            \global\@minipagefalse
            \outer@nobreak}%
      \color@endbox}
    
\def\single@{\let\baselinestretch\singlebaselinestretch\selectfont
   \parskip\singleparskip} 
\def\double@{\let\baselinestretch\doublebaselinestretch\selectfont
   \parskip\doubleparskip}
  
%  Environments for single and double spacing. Don't try these in mid
%  paragraph.
%
%  \begin{single} ... \end{single}
%  \begin{double} ... \end{double}
   
\let\single\single@ \let\endsingle\relax
\let\double\double@ \let\enddouble\relax
            
\ifLettersect@
   \renewcommand\appendix{\par \global\let\appendix\relax
      \setcounter{chapter}{0}\setcounter{section}{0}%
      \gdef\@chapapp{\appendixname}%
      \global\let\addchapcontentsline\addappcontentsline
      \gdef\thechapter{\@Alph\c@chapter}%
      \BackSingle@}
\else
   \renewcommand\appendix{\par \global\let\appendix\relax
     \setcounter{chapter}{0}\setcounter{section}{0}%
     \gdef\@chapapp{\appendixname}%
     \global\let\addchapcontentsline\addappcontentsline
     \gdef\thechapter{\@Alph\c@chapter}\BackSingle@}
\fi
 
%  Use "Table of Contents" in place of "Contents".

\renewcommand\contentsname{Table of Contents}

%  The Table of contents is required, as are a List of Tables and List of
%  Figures if non-null. These are generated automatically by the abstract
%  environment. The notitlepage option does \let\maketitle\relax. By doing
%  \chapter*{Abstract} manually, rather than using the abstract environment,
%  table of contents generation is also left up to the user. Be sure to
%  set the page number correctly in this case.
      
\renewenvironment{abstract}{%
   \maketitle\clearpage
   \setcounter{page}{2}%
   \approvalpage\clearpage
   \authorization\clearpage
   \acknowledgements\clearpage
   {\tableofcontents
    \IfFileExists{\jobname.lot}{\listoftables}{}%
    \IfFileExists{\jobname.lof}{\listoffigures}{}\clearpage}
   \chapter*{\abstractname}}   

% The first \@chapter or \part does \pagenumbering{arabic}.

\pagenumbering{roman}

%  We need information for the title page.

\def\data@#1{\expandafter
   \edef\csname #1\endcsname{\def\expandafter\noexpand\csname @#1\endcsname}
   \expandafter\let\csname @#1\endcsname\relax}

\data@{author}          \author{\GatherInfo@{fullname}\relax}
\data@{title}
\data@{degree}
\data@{degreein}
\data@{supervisor}
\data@{depthead}
\data@{commiteesig}
\data@{fullname}
\data@{university}      \university{Acadia University}
\data@{faculty}         \faculty{The Faculty of Science}
\data@{department}
\data@{history}
\data@{gradmonth}       \gradmonth{\ifcase\month\or
                           January\or February\or March\or April\or
                           May\or June\or July\or August\or September\or
                           October\or November\or December\fi}
\data@{gradyear}        \gradyear{\number\year}
\data@{signatures}      \signatures{5}
\data@{acknowledge}

%  Authorization form.

\data@{authorizationdept}
\authorizationdept{\Warning@{Missing \string\authorizationdept\space
                             for authorization form}}

%  Unused data for ubcprogramme.cls.

\data@{degreefield}
\data@{oraldate}
\data@{oraltime}
\data@{oralroom}
\data@{chair}
\data@{committee}
\data@{examiners}
\data@{external}
                           
%  Title page.

\renewenvironment{titlepage}
   {\leftskip=0pt plus 1fil \rightskip=0pt plus 1fil \parindent\z@
    \parfillskip=0pt \parskip=-1pt \advance\parskip by \titlelineskip\relax
    \def\@{\vskip14pt\vskip\titleparskip\relax}\let\\\par
    \nostretch@\normalfont
    \null\vfill}
   {\vfill\eject}

%\renewenvironment{titlepage}
%   {\leftskip=0pt plus 1fil \rightskip=0pt plus 1fil \parindent\z@
%    \parfillskip=0pt \parskip=-1pt \advance\parskip by \titlelineskip\relax
%    \def\@{\vskip14pt\vskip\titleparskip\relax}\let\\\par
%    \nostretch@\normalfont
%    \null\vfill}
%   {\vfill\eject}

\def\titleparskip{0pt}
\def\titlelineskip{0pt}

\renewcommand\maketitle{\thispagestyle{empty}\global\let\maketitle\relax
   \begin{titlepage}
     \vskip1.5in
      {\large\bfseries\GatherInfo@{title}\MakeUppercase}\@
      by\@\GatherInfo@{fullname}\relax\@
      \phantom{.}\GatherInfo@{history}\relax\phantom{.}\@
      \vskip0.5in
      Thesis\@
    submitted in partial fulfillment of\@
    the requirements of the Degree of\@
      \GatherInfo@{degree}\relax\ in\@
      \GatherInfo@{degreein}\relax.\@
%      \GatherInfo@{faculty}\MakeUppercase\@\GatherInfo@{department}\relax\@
%      We accept this thesis as conforming\par
%      to the required standard\@
%      {\@tempcnta=\@signatures\relax
%       \loop\ifnum\@tempcnta>0
%          \advance\@tempcnta by -1
%          \SigLine@\@
%       \repeat}\vskip4pt
      \vskip1.65in
      \GatherInfo@{university}\relax\@
      \GatherInfo@{gradmonth}\relax\ \GatherInfo@{gradyear}\relax\@
      \copyright\ \@author, \GatherInfo@{gradyear}\relax\@
   \end{titlepage}}

%\newcommand\approvalpage{\thispagestyle{empty}\global\let\maketitle\relax
\newcommand\approvalpage{\global\let\maketitle\relax
   \begin{titlepage}
     \vskip1.5in
   This thesis by \@author\@
   is accepted in its present form by the\@
   \GatherInfo@{department}\relax\@ 
   as satisfying the thesis requirements for the Degree of\@
      \GatherInfo@{degree}\relax.\@
%      \GatherInfo@{faculty}\MakeUppercase\@\GatherInfo@{department}\relax\@
%      We accept this thesis as conforming\par
%      to the required standard\@
%      {\@tempcnta=\@signatures\relax
%       \loop\ifnum\@tempcnta>0
%          \advance\@tempcnta by -1
%          \SigLine@\@
%       \repeat}\vskip4pt
      \vskip1.0in
Approved by the Thesis Supervisor\@
% This is a cheap hack using invisible tables but i don't know any better!
\begin{tabular}{rl}
\SigLine@  & \DateLine@  \\
\GatherInfo@{supervisor}\relax\, & \,Date
\end{tabular}\@
\vskip0.25in
Approved by the Head of the Department\@
\begin{tabular}{rl}
\SigLine@  & \DateLine@  \\
\GatherInfo@{depthead}\relax\, & \,Date
\end{tabular}\@
\vskip0.25in
Approved by the Honours Committee\@
\begin{tabular}{rl}
\SigLine@  & \DateLine@  \\
\GatherInfo@{commiteesig}\relax\, & \,Date
\end{tabular}\@
   \end{titlepage}}


\def\acknowledgements{\global\let\acknowledgements\relax
   %\clearpage
   \begingroup
      \parskip\z@ \parindent\z@ \oddsidemargin=.25in \textwidth=6.25in
      \nostretch@\normalfont
\chapter*{Acknowledgements}
%{\fontsize\@xipt{17}\selectfont
\doublespacing\GatherInfo@{acknowledge}\relax\par
\endgroup}


\def\siglinewidth{2.25in}
\def\SigLine@{\rule{\siglinewidth}{0.5pt}}
%\def\SigLine@{\leavevmode\hbox to \siglinewidth{\def\@dotsep{0.1}\Dotfill@}}


\def\datelinewidth{1.5in}
\def\DateLine@{\rule{\datelinewidth}{0.5pt}}
%\def\DateLine@{\leavevmode\hbox to \datelinewidth{\def\@dotsep{0.1}\Dotfill@}}
 
 
\def\GatherInfo@#1#2{%
   \expandafter\ifx\csname @#1\endcsname\relax
      \Warning@{Missing \expandafter\string\csname #1\endcsname\space
                for title page}%
      ``#1''%
   \else
      \expandafter#2\csname @#1\endcsname
   \fi}
      
%\def\authorization{\thispagestyle{empty}\global\let\authorization\relax
\def\authorization{\global\let\authorization\relax
   \clearpage
   \begingroup
      \parskip\z@ \parindent\z@ \oddsidemargin=.25in \textwidth=6.25in
      \nostretch@\normalfont
      %{\fontsize\@xipt{17}\selectfont
\phantom{blah}
\vskip2.0in
I, \@author, hereby grant permission to the University Librarian at
\GatherInfo@{university}\relax\ to provide copies of the thesis, on
request, on a non-profit basis.\par
\vskip1.5in
\begin{center}
\SigLine@\par
Signature of Author\par
\vskip0.5in
\SigLine@\par
Signature of Supervisor\par
\vskip0.5in
\SigLine@\par
Date
\end{center}
%In presenting this thesis in partial fulfillment of the requirements
%for an advanced degree at Acadia University,
%I agree that the Library shall make it freely available for reference
%and study. I further agree that permission for extensive copying
%of this thesis for scholarly purposes may be granted by the head
%of my department or by his or her representatives. It is understood
%that copying or publication of this thesis for financial gain
%shall not be allowed without my written permission.\par}%
%      \fontsize\@xipt{13.6}\selectfont
%      \vskip2.5in
%      {\leftskip=0pt plus 1fil \parfillskip\z@
%      (Signature)\ \vrule width2.5in height-2pt depth2.4pt\quad\null\par}%
%      \vskip2.5in
 %     \@authorizationdept\par
%Acadia University\par
%Wolfville, Nova Scotia, Canada\par
%      \vskip.3in
%Date\ \vrule width2.5in height-2pt depth2.4pt\par
   \endgroup}
      
%  Switch to double spacing at the first \chapter (not \chapter*) and
%  back to single spacing at the next \chapter*, usually generated in a
%  thebibliography environment.

\def\mainmatter{%
   \pagenumbering{arabic}\Double@
   \let\mainmatter\relax
   \let\backmatter\appendix}
\let\backmatter\relax
      
%  All chapters must be present in the table of contents.
%  Redefine \chapter* to produce a toc entry, format the mark differently
%  from \chapter and to not number the chapter.
      
\renewcommand\part{\clearpage
   \mainmatter
   \thispagestyle{plain}%
   \@tempswafalse
   \null\vfil
   \secdef\@part\@spart}
      
\def\@chapter[#1]#2{%
   \mainmatter
   \ifnum \c@secnumdepth>\m@ne\relax
      \refstepcounter{chapter}%
      \typeout{\@chapapp\space\thechapter.}%
%
%  Note that we always use the full title for the toc (#2 rather than #1)
%  since we can break the toc entry with \newtocline. The optional argument
%  is only used for the header.
%     
      \addchapcontentsline{toc}{chapter}{#2}%
   \else
      \addcontentsline{toc}{chapter}{#2}%
   \fi
   \addtocontents{lof}{\protect\addvspace{10\p@}}%
   \addtocontents{lot}{\protect\addvspace{10\p@}}%
   \@makechapterhead{#2}%
   \chaptermark{#1}%
   \@afterheading}
   
\def\@schapter#1{%
   \backmatter
   \addcontentsline{toc}{chapter}{#1}%
   \@makeschapterhead{#1}%
   \schaptermark{#1}%
   \@afterheading}
 
\renewcommand\tableofcontents{\global\let\tableofcontents\relax
   \tochook@
   \chapter*{\contentsname}%   
   \@starttoc{toc}}
      
\renewcommand\listoffigures{\global\let\listoffigures\relax
   \genhook@{figure}%
   \chapter*{\listfigurename}%
   \@starttoc{lof}}
   
\renewcommand\listoftables{\global\let\listoftables\relax
   \genhook@{table}%
   \chapter*{\listtablename}%
   \@starttoc{lot}}


